import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/dstindex/:dstindex?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'dstindex';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: 'app.views.dstindex.caption',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'dstindex', parameterName: 'dstindex' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/lite/dst-index/dst-index.vue'),
            children: [
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metamodel.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-pickup-view/meta-model-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'metamodules/:metamodule?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metamodule.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodules', parameterName: 'metamodule' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-module-pickup-view/meta-module-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'ruleitems/:ruleitem?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.ruleitem.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleitems', parameterName: 'ruleitem' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-item-pickup-view/rule-item-pickup-view.vue'),
                },
                {
                    path: 'metamodules/:metamodule?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metamodule.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodules', parameterName: 'metamodule' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-module-pickup-grid-view/meta-module-pickup-grid-view.vue'),
                },
                {
                    path: 'execresults/:execresult?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.execresult.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'execresults', parameterName: 'execresult' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/exec-result-grid-view/exec-result-grid-view.vue'),
                },
                {
                    path: 'tablesyncs/:tablesync?/editview/:editview?',
                    meta: {
                        caption: 'entities.tablesync.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'tablesyncs', parameterName: 'tablesync' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/table-sync-edit-view/table-sync-edit-view.vue'),
                },
                {
                    path: 'dabuilds/:dabuild?/dametrics/:dametric?/editview/:editview?',
                    meta: {
                        caption: 'entities.dametric.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dabuilds', parameterName: 'dabuild' },
                            { pathName: 'dametrics', parameterName: 'dametric' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dametric-edit-view/dametric-edit-view.vue'),
                },
                {
                    path: 'dametrics/:dametric?/editview/:editview?',
                    meta: {
                        caption: 'entities.dametric.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dametrics', parameterName: 'dametric' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dametric-edit-view/dametric-edit-view.vue'),
                },
                {
                    path: 'dabuilds/:dabuild?/dametrics/:dametric?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dametric.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dabuilds', parameterName: 'dabuild' },
                            { pathName: 'dametrics', parameterName: 'dametric' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dametric-grid-view/dametric-grid-view.vue'),
                },
                {
                    path: 'dametrics/:dametric?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dametric.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dametrics', parameterName: 'dametric' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dametric-grid-view/dametric-grid-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/editview/:editview?',
                    meta: {
                        caption: 'entities.dictcatalog.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-catalog-edit-view/dict-catalog-edit-view.vue'),
                },
                {
                    path: 'dareports/:dareport?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dareport.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dareports', parameterName: 'dareport' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dareport-grid-view/dareport-grid-view.vue'),
                },
                {
                    path: 'execlogs/:execlog?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.execlog.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'execlogs', parameterName: 'execlog' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/exec-log-grid-view/exec-log-grid-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/editview/:editview?',
                    meta: {
                        caption: 'entities.metamodel.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-edit-view/meta-model-edit-view.vue'),
                },
                {
                    path: 'tablesyncs/:tablesync?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.tablesync.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'tablesyncs', parameterName: 'tablesync' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/table-sync-grid-view/table-sync-grid-view.vue'),
                },
                {
                    path: 'ruleitems/:ruleitem?/editview/:editview?',
                    meta: {
                        caption: 'entities.ruleitem.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleitems', parameterName: 'ruleitem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-item-edit-view/rule-item-edit-view.vue'),
                },
                {
                    path: 'execresults/:execresult?/editview/:editview?',
                    meta: {
                        caption: 'entities.execresult.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'execresults', parameterName: 'execresult' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/exec-result-edit-view/exec-result-edit-view.vue'),
                },
                {
                    path: 'execlogs/:execlog?/editview/:editview?',
                    meta: {
                        caption: 'entities.execlog.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'execlogs', parameterName: 'execlog' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/exec-log-edit-view/exec-log-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'dacharts/:dachart?/editview/:editview?',
                    meta: {
                        caption: 'entities.dachart.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dacharts', parameterName: 'dachart' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dachart-edit-view/dachart-edit-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metamodel.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-grid-view/meta-model-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dictcatalog.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-catalog-grid-view/dict-catalog-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metaentity.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metaentity.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
                },
                {
                    path: 'ruleitems/:ruleitem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ruleitem.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleitems', parameterName: 'ruleitem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-item-grid-view/rule-item-grid-view.vue'),
                },
                {
                    path: 'dabuilds/:dabuild?/editview/:editview?',
                    meta: {
                        caption: 'entities.dabuild.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dabuilds', parameterName: 'dabuild' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dabuild-edit-view/dabuild-edit-view.vue'),
                },
                {
                    path: 'ruleitems/:ruleitem?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.ruleitem.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleitems', parameterName: 'ruleitem' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-item-pickup-grid-view/rule-item-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/editview/:editview?',
                    meta: {
                        caption: 'entities.dstsystem.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-system-edit-view/dst-system-edit-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-pickup-view/dst-data-source-pickup-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metamodel.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-pickup-grid-view/meta-model-pickup-grid-view.vue'),
                },
                {
                    path: 'ruleengines/:ruleengine?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ruleengine.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleengines', parameterName: 'ruleengine' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-engine-grid-view/rule-engine-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/dictoptions/:dictoption?/editview/:editview?',
                    meta: {
                        caption: 'entities.dictoption.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'dictoptions', parameterName: 'dictoption' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-option-edit-view/dict-option-edit-view.vue'),
                },
                {
                    path: 'dictoptions/:dictoption?/editview/:editview?',
                    meta: {
                        caption: 'entities.dictoption.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictoptions', parameterName: 'dictoption' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-option-edit-view/dict-option-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
                },
                {
                    path: 'dacharts/:dachart?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dachart.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dacharts', parameterName: 'dachart' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dachart-grid-view/dachart-grid-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-pickup-grid-view/dst-data-source-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dstsystem.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-system-grid-view/dst-system-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/editview/:editview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-edit-view/dst-data-source-edit-view.vue'),
                },
                {
                    path: 'dabuilds/:dabuild?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dabuild.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dabuilds', parameterName: 'dabuild' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dabuild-grid-view/dabuild-grid-view.vue'),
                },
                {
                    path: 'dareports/:dareport?/editview/:editview?',
                    meta: {
                        caption: 'entities.dareport.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dareports', parameterName: 'dareport' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/analysis/dareport-edit-view/dareport-edit-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/dictoptions/:dictoption?/grideditview/:grideditview?',
                    meta: {
                        caption: 'entities.dictoption.views.grideditview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'dictoptions', parameterName: 'dictoption' },
                            { pathName: 'grideditview', parameterName: 'grideditview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-option-grid-edit-view/dict-option-grid-edit-view.vue'),
                },
                {
                    path: 'dictoptions/:dictoption?/grideditview/:grideditview?',
                    meta: {
                        caption: 'entities.dictoption.views.grideditview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictoptions', parameterName: 'dictoption' },
                            { pathName: 'grideditview', parameterName: 'grideditview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-option-grid-edit-view/dict-option-grid-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.dictcatalog.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-catalog-pickup-grid-view/dict-catalog-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/editview/:editview?',
                    meta: {
                        caption: 'entities.metaentity.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/editview/:editview?',
                    meta: {
                        caption: 'entities.metaentity.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-grid-view/dst-data-source-grid-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/fileuploadoptionview/:fileuploadoptionview?',
                    meta: {
                        caption: 'entities.metamodel.views.fileuploadoptionview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'fileuploadoptionview', parameterName: 'fileuploadoptionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-file-upload-option-view/meta-model-file-upload-option-view.vue'),
                },
                {
                    path: 'ruleengines/:ruleengine?/editview/:editview?',
                    meta: {
                        caption: 'entities.ruleengine.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'ruleengines', parameterName: 'ruleengine' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/rule/rule-engine-edit-view/rule-engine-edit-view.vue'),
                },
                {
                    path: 'dictcatalogs/:dictcatalog?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.dictcatalog.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/dict/dict-catalog-pickup-view/dict-catalog-pickup-view.vue'),
                },
            ...indexRoutes,
            ],
        },
    {
        path: '/dabuilds/:dabuild?/dametrics/:dametric?/editview/:editview?',
        meta: {
            caption: 'entities.dametric.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dabuilds', parameterName: 'dabuild' },
                { pathName: 'dametrics', parameterName: 'dametric' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dametric-edit-view/dametric-edit-view.vue'),
    },
    {
        path: '/dametrics/:dametric?/editview/:editview?',
        meta: {
            caption: 'entities.dametric.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dametrics', parameterName: 'dametric' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dametric-edit-view/dametric-edit-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metamodel.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-pickup-grid-view/meta-model-pickup-grid-view.vue'),
    },
    {
        path: '/dabuilds/:dabuild?/gridview/:gridview?',
        meta: {
            caption: 'entities.dabuild.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dabuilds', parameterName: 'dabuild' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dabuild-grid-view/dabuild-grid-view.vue'),
    },
    {
        path: '/tablesyncs/:tablesync?/editview/:editview?',
        meta: {
            caption: 'entities.tablesync.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'tablesyncs', parameterName: 'tablesync' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/table-sync-edit-view/table-sync-edit-view.vue'),
    },
    {
        path: '/dacharts/:dachart?/gridview/:gridview?',
        meta: {
            caption: 'entities.dachart.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dacharts', parameterName: 'dachart' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dachart-grid-view/dachart-grid-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/dictoptions/:dictoption?/editview/:editview?',
        meta: {
            caption: 'entities.dictoption.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'dictoptions', parameterName: 'dictoption' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-option-edit-view/dict-option-edit-view.vue'),
    },
    {
        path: '/dictoptions/:dictoption?/editview/:editview?',
        meta: {
            caption: 'entities.dictoption.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dictoptions', parameterName: 'dictoption' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-option-edit-view/dict-option-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/editview/:editview?',
        meta: {
            caption: 'entities.dstsystem.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-system-edit-view/dst-system-edit-view.vue'),
    },
    {
        path: '/metamodules/:metamodule?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metamodule.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodules', parameterName: 'metamodule' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-module-pickup-grid-view/meta-module-pickup-grid-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.dstdatasource.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-pickup-view/dst-data-source-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/editview/:editview?',
        meta: {
            caption: 'entities.dstdatasource.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-edit-view/dst-data-source-edit-view.vue'),
    },
    {
        path: '/dareports/:dareport?/gridview/:gridview?',
        meta: {
            caption: 'entities.dareport.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dareports', parameterName: 'dareport' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dareport-grid-view/dareport-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/fileuploadoptionview/:fileuploadoptionview?',
        meta: {
            caption: 'entities.metamodel.views.fileuploadoptionview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'fileuploadoptionview', parameterName: 'fileuploadoptionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-file-upload-option-view/meta-model-file-upload-option-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/dictoptions/:dictoption?/grideditview/:grideditview?',
        meta: {
            caption: 'entities.dictoption.views.grideditview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'dictoptions', parameterName: 'dictoption' },
                { pathName: 'grideditview', parameterName: 'grideditview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-option-grid-edit-view/dict-option-grid-edit-view.vue'),
    },
    {
        path: '/dictoptions/:dictoption?/grideditview/:grideditview?',
        meta: {
            caption: 'entities.dictoption.views.grideditview.caption',
            info:'',
            parameters: [
                { pathName: 'dictoptions', parameterName: 'dictoption' },
                { pathName: 'grideditview', parameterName: 'grideditview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-option-grid-edit-view/dict-option-grid-edit-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metamodel.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-pickup-view/meta-model-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metaentity.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metaentity.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/editview/:editview?',
        meta: {
            caption: 'entities.metaentity.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/editview/:editview?',
        meta: {
            caption: 'entities.metaentity.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/editview/:editview?',
        meta: {
            caption: 'entities.metamodel.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-edit-view/meta-model-edit-view.vue'),
    },
    {
        path: '/metamodules/:metamodule?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metamodule.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodules', parameterName: 'metamodule' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-module-pickup-view/meta-module-pickup-view.vue'),
    },
    {
        path: '/tablesyncs/:tablesync?/gridview/:gridview?',
        meta: {
            caption: 'entities.tablesync.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'tablesyncs', parameterName: 'tablesync' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/table-sync-grid-view/table-sync-grid-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/gridview/:gridview?',
        meta: {
            caption: 'entities.dictcatalog.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-catalog-grid-view/dict-catalog-grid-view.vue'),
    },
    {
        path: '/execlogs/:execlog?/gridview/:gridview?',
        meta: {
            caption: 'entities.execlog.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'execlogs', parameterName: 'execlog' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/exec-log-grid-view/exec-log-grid-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.dictcatalog.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-catalog-pickup-grid-view/dict-catalog-pickup-grid-view.vue'),
    },
    {
        path: '/ruleitems/:ruleitem?/editview/:editview?',
        meta: {
            caption: 'entities.ruleitem.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleitems', parameterName: 'ruleitem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-item-edit-view/rule-item-edit-view.vue'),
    },
    {
        path: '/dabuilds/:dabuild?/editview/:editview?',
        meta: {
            caption: 'entities.dabuild.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dabuilds', parameterName: 'dabuild' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dabuild-edit-view/dabuild-edit-view.vue'),
    },
    {
        path: '/ruleengines/:ruleengine?/gridview/:gridview?',
        meta: {
            caption: 'entities.ruleengine.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleengines', parameterName: 'ruleengine' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-engine-grid-view/rule-engine-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.dstdatasource.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-pickup-grid-view/dst-data-source-pickup-grid-view.vue'),
    },
    {
        path: '/ruleitems/:ruleitem?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.ruleitem.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleitems', parameterName: 'ruleitem' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-item-pickup-view/rule-item-pickup-view.vue'),
    },
    {
        path: '/dareports/:dareport?/editview/:editview?',
        meta: {
            caption: 'entities.dareport.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dareports', parameterName: 'dareport' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dareport-edit-view/dareport-edit-view.vue'),
    },
    {
        path: '/execlogs/:execlog?/editview/:editview?',
        meta: {
            caption: 'entities.execlog.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'execlogs', parameterName: 'execlog' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/exec-log-edit-view/exec-log-edit-view.vue'),
    },
    {
        path: '/ruleengines/:ruleengine?/editview/:editview?',
        meta: {
            caption: 'entities.ruleengine.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleengines', parameterName: 'ruleengine' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-engine-edit-view/rule-engine-edit-view.vue'),
    },
    {
        path: '/execresults/:execresult?/gridview/:gridview?',
        meta: {
            caption: 'entities.execresult.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'execresults', parameterName: 'execresult' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/exec-result-grid-view/exec-result-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/gridview/:gridview?',
        meta: {
            caption: 'entities.metaentity.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/gridview/:gridview?',
        meta: {
            caption: 'entities.metaentity.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.dictcatalog.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-catalog-pickup-view/dict-catalog-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/gridview/:gridview?',
        meta: {
            caption: 'entities.dstsystem.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-system-grid-view/dst-system-grid-view.vue'),
    },
    {
        path: '/dictcatalogs/:dictcatalog?/editview/:editview?',
        meta: {
            caption: 'entities.dictcatalog.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dictcatalogs', parameterName: 'dictcatalog' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/dict/dict-catalog-edit-view/dict-catalog-edit-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/gridview/:gridview?',
        meta: {
            caption: 'entities.dstdatasource.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-grid-view/dst-data-source-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metaentity.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metaentity.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/execresults/:execresult?/editview/:editview?',
        meta: {
            caption: 'entities.execresult.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'execresults', parameterName: 'execresult' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/exec-result-edit-view/exec-result-edit-view.vue'),
    },
    {
        path: '/dacharts/:dachart?/editview/:editview?',
        meta: {
            caption: 'entities.dachart.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dacharts', parameterName: 'dachart' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dachart-edit-view/dachart-edit-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/gridview/:gridview?',
        meta: {
            caption: 'entities.metamodel.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-grid-view/meta-model-grid-view.vue'),
    },
    {
        path: '/ruleitems/:ruleitem?/gridview/:gridview?',
        meta: {
            caption: 'entities.ruleitem.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleitems', parameterName: 'ruleitem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-item-grid-view/rule-item-grid-view.vue'),
    },
    {
        path: '/dabuilds/:dabuild?/dametrics/:dametric?/gridview/:gridview?',
        meta: {
            caption: 'entities.dametric.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dabuilds', parameterName: 'dabuild' },
                { pathName: 'dametrics', parameterName: 'dametric' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dametric-grid-view/dametric-grid-view.vue'),
    },
    {
        path: '/dametrics/:dametric?/gridview/:gridview?',
        meta: {
            caption: 'entities.dametric.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dametrics', parameterName: 'dametric' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/analysis/dametric-grid-view/dametric-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/ruleitems/:ruleitem?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.ruleitem.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ruleitems', parameterName: 'ruleitem' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/rule/rule-item-pickup-grid-view/rule-item-pickup-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/lock',
            name: 'lock',
            meta: {  
                caption: '锁屏',
                viewType: 'lock',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                next();
            },
            component: () => import('@components/app-lock/app-lock.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'dstindex'
        },
    ],
});
// 解决路由跳转路由重复时报错
const originalPush = Router.prototype.push
Router.prototype.push = function push(location: any) {
    let result: any = originalPush.call(this, location);
    return result.catch((err: any) => err);
}
export default router;
